@@ -1,3 +1,5 @@
+import inspect
+
 from django import forms
 from django.core import serializers
 
@@ -34,16 +36,27 @@ class Export(forms.Form):
         self.fieldsets = (('Options', {'fields': ('export_format', 'export_fields', 'export_order_by', 'export_order_direction')}), ('Filters', {'description': 'Objects will be filtered to match the criteria as specified in the fields below. If a value is not specified for a field the field is ignored during the filter process.', 'fields': []}))
 
         field_choices = []
-        for name, field in forms.models.fields_for_model(model).iteritems():
-            if field.__class__ in [forms.models.ModelChoiceField, forms.models.ModelMultipleChoiceField]:
-                self.fields[name] = getattr(fields, field.__class__.__name__)(field, field.queryset)
+        form_fields = forms.models.fields_for_model(model)
+        for field in model._meta.fields:
+            name = field.name
+            if name not in form_fields.keys():
+                continue
+            form_field = form_fields[name]
+            if form_field.__class__ in [forms.models.ModelChoiceField, forms.models.ModelMultipleChoiceField]:
+                self.fields[name] = getattr(fields, field.__class__.__name__)(form_field, form_field.queryset)
             else:
-                self.fields[name] = getattr(fields, field.__class__.__name__)(field)
+                try:
+                    self.fields[name] = getattr(fields, field.__class__.__name__)(form_field)
+                except AttributeError:
+                    for parent_field in inspect.getmro(field.__class__):
+                        if parent_field.__module__ == 'django.db.models.fields':
+                            self.fields[name] = getattr(fields, parent_field.__name__)(form_field)
+                            break
 
             if name not in self.fieldsets[1][1]['fields']:
                 self.fieldsets[1][1]['fields'].append(name)
 
-            field_choices.append([name, field.label.capitalize()])
+            field_choices.append([name, form_field.label.capitalize()])
 
         self.fields['export_fields'].choices = field_choices
         self.fields['export_order_by'].choices = field_choices
